import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * EarthObjects are the basic objects of a game. An Earth object is a simple object which doesn't do anything.
 * The only funktion of the object is that the player can stand on it and can't move through it.
 * 
 * EarthObjects can be used in every size. Also some EarthObjects can be used as a help object (e.g. for doors).
 * These help objects aren't recoginized by the levelBluePrint method and so they don't exist in the game.
 * They are only set by the objects which use them.
 * 
 * @author Gevater_Tod4711
 * @version 1.0
 */
public class EarthObject extends Background
{
    private boolean helpObject;
    
    public EarthObject(int width, int height) {
        this(width, height, false);
    }
    public EarthObject(int width, int height, boolean helpObject) {
        super(new Earth());
        this.width = width;
        this.height = height;
        this.helpObject = helpObject;
        getImage().clear();
        getImage().scale(width, height);
        if (helpObject) {
            getImage().clear();
        }
        else if (Settings.texturEarth != null) {
            createTextur();
        }
        else {
            getImage().setColor(material.getMaterialColor());
            getImage().fill();
        }
    }
    
    public void createTextur() {
        GreenfootImage textur = new GreenfootImage(Settings.texturEarth);
        for (int i = 0; i < width; i += textur.getWidth()) {
            for (int j = 0; j < height; j += textur.getHeight()) {
                getImage().drawImage(textur, i, j);
            }
        }
    }
    public void createTextur(GreenfootImage textur) {
        for (int i = 0; i < width; i += textur.getWidth()) {
            for (int j = 0; j < height; j += textur.getHeight()) {
                getImage().drawImage(textur, i, j);
            }
        }
    }
    
    public boolean isHelpObject() {
        return helpObject;
    }
}