import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;
import java.util.List;

/**
 * Write a description of class GravityWorld here.
 * 
 * @author Gevater_Tod4711
 * @version 1.0
 */
public class GravityWorld extends ScrollingWorld
{
    public static final double GRAVITY = Settings.GRAVITY;
    
    private final Material[] materials = {new Earth(), new Air(), new Water(), new Lava(), new Rope()};
    
    private static int gravityDirection = 0;
    private static int level = 0;
    
    private int editModeCounter = 0;
    private int editModeSpeed = 1;
    
    protected int totalXMovement = 0;
    protected int totalYMovement = 0;
    
    private boolean addHelplines = false;
    private boolean editMode = false;
    private boolean pauseMusic = false;
    
    private Actor editedActor;
    
    public GravityWorld() {
        super(500, 500, 1);
        setPaintOrder(Menu.class, Hero.class, Player.class, MessageBox.class, EarthObject.class, LavaObject.class, Background.class, SpawnPoint.class, EndGate.class, Textur.class);
        addObject(new MainMenu(), getWidth()/2, getHeight()/2);
        Greenfoot.setSpeed(52);
        Greenfoot.start();
    }
    
    public void act() {
        if (Greenfoot.isKeyDown("escape") && getObjects(MainMenu.class).isEmpty() && getObjects(EndScreen.class).isEmpty() && getObjects(BreakMenu.class).isEmpty()) {
            if (Settings.pauseSound != null) {
                GreenfootSound sound = new GreenfootSound(Settings.pauseSound);
                sound.setVolume(Settings.soundVolume);
                sound.play();
            }
            addObject(new BreakMenu(), getWidth()/2, getHeight()/2);
        }
        if (editMode) {
            editMode();
        }
    }
    
    /**
     * This method starts all the levels of your game.
     * 
     * @param levelNumber
     *      The number of the level you want to start.
     */
    public void startLevel(int levelNumber) {
        level = levelNumber;
        removeAllObjects();
        setGravityDirection(0);
        try {
            new LevelConstructor(this).buildLevel(levelNumber);
        }
        catch (IllegalArgumentException iae) {
            iae.printStackTrace();
        }
    }
    /**
     * If the currentLevel is not the final level this method starts the next level.
     */
    public boolean nextLevel() {
        if (LevelConstructor.levelNumber > level) {
            startLevel(level+1);
            return true;
        }
        return false;
    }
    /**
     * Restart the current level.
     */
    public void restartLevel() {
        startLevel(level);
    }
    
    /**
     * Using this method a blueprint of your current level will be printed on the console.
     * You just have to add everything you want to have in your level and when you're ready execute this mehtod.
     * 
     * The blueprint will rebuild your level every time you call the belonging method in the LevelConstructor class (which is normaly calld by the world).
     * 
     * It's advisable to create blueprints of your level even when it's not ready. Because if you haven't got any blueprint and you reset the scenario your whole level gets deleted. 
     * If you have got a blueprint only the last part (since the last blueprint) gets lost.
     */
    public void printLevelBlueprint() {
        List<Actor> list = getObjects(Actor.class);
        for (Actor actor : list) {
            if (actor instanceof Background) {
                if (actor instanceof EarthObject) {
                    EarthObject object = (EarthObject) actor;
                    if (!object.isHelpObject()) {
                        System.out.println("        world.addObject(new " + ("" + object.getClass()).substring(6) + "(" + object.getWidth() + ", " + object.getHeight() + "), " + (object.getX() - totalXMovement) + 
                            ", " + (object.getY() - totalYMovement) + ");");
                    }
                }
                else if (actor instanceof LavaObject) {
                    LavaObject object = (LavaObject) actor;
                    System.out.println("        world.addObject(new " + ("" + object.getClass()).substring(6) + "(" + object.getWidth() + ", " + object.getHeight() + "), " + (object.getX() - totalXMovement) + 
                        ", " + (object.getY() - totalYMovement) + ");");
                }
            }
            else if (actor instanceof SpawnPoint) {
                SpawnPoint object = (SpawnPoint) actor;
                if (!((object.getX() - totalXMovement) == getWidth()/2 && (object.getY() - totalYMovement) == getHeight()/2)) {
                    System.out.println("        world.addObject(new " + ("" + object.getClass()).substring(6) + "(false), " + 
                        (object.getX() - totalXMovement) + ", " + (object.getY() - totalYMovement) + ");");
                }
            }
            else if (actor instanceof MessageBox) {
                MessageBox object = (MessageBox) actor;
                System.out.println("        world.addObject(new " + ("" + object.getClass()).substring(6) + "(" + object.getTextAsString() + ", " + object.getFontSize() + ", new Color(" + 
                    object.getTextColor().getRed() + ", " + object.getTextColor().getGreen() + ", " + object.getTextColor().getBlue() + ", " + object.getTextColor().getAlpha() + "), new Color(" + 
                    object.getBackgroundColor().getRed() + ", " + object.getBackgroundColor().getGreen() + ", " + object.getBackgroundColor().getBlue() + ", " + object.getBackgroundColor().getAlpha() + 
                    ")), " + (object.getX() - totalXMovement) + ", " + (object.getY() - totalYMovement) + ");");
            }
            else if (actor instanceof EndGate) {
                EndGate object = (EndGate) actor;
                System.out.println("        world.addObject(new " + ("" + object.getClass()).substring(6) + "(), " + (object.getX() - totalXMovement) + ", " + (object.getY() - totalYMovement) + ");");
            }
        }
        System.out.println("        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);\n        world.addObject(new Textur(), " + getWidth()/2 + ", " + getHeight()/2 + 
            ");\n        Hero hero = new Hero();\n        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);\n\nDon't forget to klear the terminal after you copied this.\n");
    }
    
    /**
     * Clear the world and add a new hero to create a new level.
     */
    public void createNewLevel() {
        removeAllObjects();
        resetTotalMovement();
        addObject(new Hero(), getWidth()/2, getHeight()/2);
        addHelplines();
        startEditMode();
    }
    
    /**
     * Reset the position of the ScrollingActor and set the position of all other objects in the world.
     */
    public void resetPlayersPosition(ScrollingActor scrollingActor) {
        int xMovement = (int) ((double) getWidth()/2 - scrollingActor.getExactX());
        int yMovement = (int) ((double) getHeight()/2 - scrollingActor.getExactY());
        totalXMovement += xMovement;
        totalYMovement += yMovement;
        List<Actor> actors = getObjects(Actor.class);
        for (Actor actor : actors) {
            if (actor instanceof ScrollingActor) {
                ((ScrollingActor) actor).setLocation(actor.getX() + xMovement, actor.getY() + yMovement, false);
            }
            else if (actor instanceof Menu || actor instanceof FixedObject) {
                ;
            }
            else {
                actor.setLocation(actor.getX() + xMovement, actor.getY() + yMovement);
            }
        }
        if (textur != null) {
            createTextur();
        }
        if (addHelplines) {
            drawHelplines();
        }
    }
    
    /**
     * Start the edit mode of the world.
     * 
     * While the edit mode is on the players will not move but a specific object can be moved using the arrow keys.
     * To select the object that should be moved just click on it.
     * The movement can be made faster or slower using the keys '1' (slow) to '4' (fast).
     * To stop the edit mode pause the world and execute the method endEditMode in world.
     */
    public void startEditMode() {
        editMode = true;
    }
    
    /**
     * Stops the edit mode.
     */
    public void endEditeMode() {
        editMode = false;
        editedActor = null;
    }
    
    /**
     * Move the edited object when the edit mode is activated.
     */
    protected void editMode() {
        if (Greenfoot.mouseClicked(null)) {
            MouseInfo mouse = Greenfoot.getMouseInfo();
            if (mouse != null) {
                List<Actor> actors = getObjectsAt(mouse.getX(), mouse.getY(), Actor.class);
                if (!actors.isEmpty()) {
                    editedActor = actors.get(0);
                    if (editedActor instanceof Hero) {
                        editModeSpeed = 25;
                    }
                    else {
                        editModeSpeed = 1;
                    }
                }
            }
        }
        if (editModeCounter >= 5) {
            if (editedActor != null) {
                if (Greenfoot.isKeyDown("up")) {
                    editedActor.setLocation(editedActor.getX(), editedActor.getY() - editModeSpeed);
                }
                if (Greenfoot.isKeyDown("down")) {
                    editedActor.setLocation(editedActor.getX(), editedActor.getY() + editModeSpeed);
                }
                if (Greenfoot.isKeyDown("left")) {
                    editedActor.setLocation(editedActor.getX() - editModeSpeed, editedActor.getY());
                }
                if (Greenfoot.isKeyDown("right")) {
                    editedActor.setLocation(editedActor.getX() + editModeSpeed, editedActor.getY());
                }
                if (Greenfoot.isKeyDown("backspace")) {
                    removeObject(editedActor);
                    editedActor = null;
                }
                if (Greenfoot.isKeyDown("1")) {
                    editModeSpeed = 1;
                }
                else if (Greenfoot.isKeyDown("2")) {
                    editModeSpeed = 5;
                }
                else if (Greenfoot.isKeyDown("3")) {
                    editModeSpeed = 25;
                }
                else if (Greenfoot.isKeyDown("4")) {
                    editModeSpeed = 100;
                }
            }
            editModeCounter = 0;
        }
        else {
            editModeCounter++;
        }
    }
    
    /**
     * Add helplines to the world that help you constructing the levels.
     */
    public void addHelplines() {
        addHelplines = true;
        drawHelplines();
    }
    
    /**
     * Remove the helplines.
     */
    public void removeHelplines() {
        addHelplines = false;
        getBackground().clear();
    }
    
    /**
     * Draw the helplines into the world.
     */
    protected void drawHelplines() {
        int x;
        int y;
        if (totalXMovement > 0) {
            for (x = totalXMovement; x > 0; x -= 1000) {
                ;
            }
        }
        else {
            for (x = totalXMovement; x < 0; x += 1000) {
                ;
            }
            x -= 1000;
        }
        if (totalYMovement > 0) {
            for (y = totalYMovement; y > 0; y -= 1000) {
                ;
            }
        }
        else {
            for (y = totalYMovement; y < 0; y += 1000) {
                ;
            }
            y -= 1000;
        }
        getBackground().setColor(Color.white);
        getBackground().fill();
        getBackground().setColor(Color.black);
        for (int i = x; i < getWidth(); i += 1000) {
            getBackground().fillRect(i-1, 0, 3, getHeight());
        }
        for (int i = x; i < getWidth(); i += 100) {
            getBackground().fillRect(i, 0, 1, getHeight());
        }
        for (int i = y; i < getHeight(); i += 1000) {
            getBackground().fillRect(0, i-1, getWidth(), 3);
        }
        for (int i = y; i < getHeight(); i += 100) {
            getBackground().fillRect(0, i, getWidth(), 1);
        }
    }
    
    /**
     * Remove all objects that currently are in the world.
     */
    public void removeAllObjects() {
        removeObjects(getObjects(null));
    }
    
    /**
     * Remove all objects that currently are in the world with the exception of the actor given as parameter.
     * 
     * @param actor
     *      The only object that will not be removed from the world.
     */
    public void removeAllObjectsBut(Actor actor) {
        List<Actor> allActors = getObjects(null);
        for (Actor a : allActors) {
            if (!a.equals(actor)) {
                removeObject(a);
            }
        }
    }
    
    /**
     * Reset the starting position of your hero.
     * If you exectue this method the current position of your hero will be his starting position.
     */
    public void resetTotalMovement() {
        totalXMovement = 0;
        totalYMovement = 0;
    }
    
    /**
     * Returns the number of the material at a specific position in the world.
     * 
     * @param x
     *      The x coordinate of the point which material number you want to get.
     * 
     * @param y
     *      The y coordinate of the point which material number you want to get.
     * 
     * @return
     *      Returns the number of the material at the checked point.
     */
    public int getMaterialNumberAt(int x, int y) {
        Material material = getMaterialAt(x, y);
        return (material != null ? material.getMaterialNumber() : 0);
    }
    
    /**
     * Returns the material at a specific position in the world.
     * 
     * @param x
     *      The x coordinate of the point which material you want to get.
     * 
     * @param y
     *      The y coordinate of the point which material you want to get.
     * 
     * @return
     *      Returns the material at the checked point or null if the material is unknown.
     */
    public Material getMaterialAt(int x, int y) {
        List<Background> bgObjects = getObjectsAt(x, y, Background.class);
        if (bgObjects.isEmpty()) {
            return materials[1];
        }
        for (Material material : materials) {
            for (Background bg : bgObjects) {
                if (bg.getMaterial().getClass().equals(material.getClass())) {
                    return material;
                }
            }
        }
        System.out.println("World: Material unknown " + x + " " + y);
        return null;
    }
    
    /**
     * Check whether the edit mode is activated.
     * 
     * @return
     *      Returns true if the worlds' edit mode is activated.
     */
    public boolean isEditMode() {
        return editMode;
    }
    
    /**
     * Get the number of the current level.
     * 
     * @return
     *      The number of the level that is currently played.
     */
    public int getLevel() {
        return level;
    }
    
    public int getGravityDirection() {
        return gravityDirection;
    }
    public void setGravityDirection(int gravityDirection) throws IllegalArgumentException {
        if (gravityDirection < 0 || gravityDirection > 3) {
            throw new IllegalArgumentException("The gravityDirection must be between 0 and 3 (inclusive).");
        }
        this.gravityDirection = gravityDirection;
    }
}