import greenfoot.*;
import java.awt.Color;

/**
 * The level constructor is the blueprint for all levels in a game.
 * All levelblueprints that are printed by the worldmethod printLevelBlueprint() should be saved in this class.
 * 
 * The building of the levels is done by the world. The programmer only has to build the levels and save the blue prints here.
 * 
 * @author Gevater_Tod4711
 * @version 1.0
 */
public class LevelConstructor  
{
    public static final int levelNumber = 10;
    
    private World world;
    
    public LevelConstructor(World world) {
        this.world = world;
    }
    
    public void buildLevel(int levelNumber) throws IllegalArgumentException {
        switch (levelNumber) {
            case -1:
                buildTutorial();
                break;
            case 1:
                buildLevel1();
                break;
            case 2:
                buildLevel2();
                break;
            case 3:
                buildLevel3();
                break;
            case 4:
                buildLevel4();
                break;
            case 5:
                buildLevel5();
                break;
            case 6:
                buildLevel6();
                break;
            case 7:
                buildLevel7();
                break;
            case 8:
                buildLevel8();
                break;
            case 9:
                buildLevel9();
                break;
            case 10:
                buildLevel10();
                break;
            default:
                throw new IllegalArgumentException("The level (" + levelNumber + ") you are trying to build is not existing.");
        }
    }
    
    public void buildTutorial() {
        world.addObject(new EndGate(), -50, -650);
        world.addObject(new SpawnPoint(false), -150, -1350);
        world.addObject(new LavaObject(200, 500), -500, -1150);
        world.addObject(new EarthObject(500, 100), 250, 350);
        world.addObject(new EarthObject(100, 300), 50, 150);
        world.addObject(new EarthObject(400, 100), 300, -150);
        world.addObject(new EarthObject(100, 400), 450, 100);
        world.addObject(new EarthObject(100, 400), -250, -100);
        world.addObject(new EarthObject(300, 100), -150, 150);
        world.addObject(new EarthObject(500, 100), -150, -550);
        world.addObject(new EarthObject(100, 300), -350, -350);
        world.addObject(new EarthObject(100, 300), 50, -750);
        world.addObject(new EarthObject(100, 200), 250, -800);
        world.addObject(new EarthObject(700, 100), 750, -250);
        world.addObject(new EarthObject(800, 100), 700, -750);
        world.addObject(new EarthObject(100, 400), 1050, -500);
        world.addObject(new EarthObject(200, 100), 800, -550);
        world.addObject(new EarthObject(100, 200), 550, -500);
        world.addObject(new EarthObject(100, 100), 250, -650);
        world.addObject(new EarthObject(100, 100), 350, -450);
        world.addObject(new EarthObject(100, 100), 850, -350);
        world.addObject(new EarthObject(500, 100), 150, -1150);
        world.addObject(new EarthObject(100, 300), -50, -950);
        world.addObject(new EarthObject(100, 100), 250, -1050);
        world.addObject(new EarthObject(100, 100), 50, -950);
        world.addObject(new EarthObject(100, 700), 650, -1150);
        world.addObject(new EarthObject(100, 100), 550, -1150);
        world.addObject(new EarthObject(1000, 100), 100, -1450);
        world.addObject(new EarthObject(200, 100), 200, -1350);
        world.addObject(new EarthObject(100, 200), -150, -1200);
        world.addObject(new EarthObject(300, 100), -550, -1450);
        world.addObject(new EarthObject(100, 500), -650, -1150);
        world.addObject(new EarthObject(300, 100), -550, -850);
        world.addObject(new EarthObject(100, 300), -450, -650);
        world.addObject(new EarthObject(100, 100), -150, -650);
        world.addObject(new MessageBox("Hello,\nin this tutorial you'll\nlearn about the controlls\nof this game", 35, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), 251, 78);
        world.addObject(new MessageBox("Click 'up' to continue", 35, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), 249, 200);
        world.addObject(new MessageBox("In this game you\ncan't realy move.\nYou have to change\nthe gravity to move.", 35, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), -61, -209);
        world.addObject(new MessageBox("'up' to continue", 35, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), -97, 51);
        world.addObject(new MessageBox("Try moving arround\nfor a while to get a\nfeeling for the controlls", 35, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), 267, -551);
        world.addObject(new MessageBox("Try jumping\nwith 'space'", 35, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), 255, -951);
        world.addObject(new MessageBox("Try not to\nfall into lava.\nWhen you touch\nthe lava you'll be\nset to the last\nspawnpoint you\nreached", 30, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), -300, -1218);
        world.addObject(new MessageBox("When you reach\nan endgate the level\nis over and you\ncan start the next level", 30, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), -238, -801);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel1() {
        world.addObject(new EndGate(), 750, -350);
        world.addObject(new SpawnPoint(false), 1150, -1050);
        world.addObject(new LavaObject(300, 100), 550, -950);
        world.addObject(new LavaObject(900, 100), 750, -1150);
        world.addObject(new LavaObject(100, 500), 950, -750);
        world.addObject(new LavaObject(100, 600), 1150, -600);
        world.addObject(new EarthObject(500, 200), 250, 400);
        world.addObject(new EarthObject(100, 500), 50, 50);
        world.addObject(new EarthObject(100, 500), 450, 50);
        world.addObject(new EarthObject(300, 300), 250, -450);
        world.addObject(new EarthObject(200, 200), 600, -100);
        world.addObject(new EarthObject(200, 200), -100, -100);
        world.addObject(new EarthObject(100, 500), 650, -450);
        world.addObject(new EarthObject(100, 500), -150, -450);
        world.addObject(new EarthObject(300, 200), -50, -800);
        world.addObject(new EarthObject(300, 200), 550, -800);
        world.addObject(new EarthObject(100, 100), 250, -650);
        world.addObject(new EarthObject(100, 100), 150, -850);
        world.addObject(new EarthObject(100, 100), 350, -850);
        world.addObject(new EarthObject(200, 300), 100, -1050);
        world.addObject(new EarthObject(1000, 200), 500, -1300);
        world.addObject(new EarthObject(100, 100), 250, -1150);
        world.addObject(new EarthObject(100, 100), 350, -950);
        world.addObject(new EarthObject(300, 200), 1150, -1300);
        world.addObject(new EarthObject(100, 1000), 1250, -700);
        world.addObject(new EarthObject(200, 600), 800, -700);
        world.addObject(new EarthObject(500, 100), 950, -250);
        world.addObject(new EarthObject(100, 100), 950, -450);
        world.addObject(new EarthObject(100, 100), 1150, -950);
        world.addObject(new MessageBox("Use the arrow keys to\nchange the gravity's direction", 30, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), 250, 100);
        world.addObject(new MessageBox("Try to jump\n with space", 30, new Color(0, 0, 0, 255), new Color(0, 0, 0, 0)), 1020, -1050);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel2() {
        world.addObject(new EndGate(), 2050, 1450);
        world.addObject(new EarthObject(100, 100), 2050, 1550);
        world.addObject(new EarthObject(1500, 200), 750, 400);
        world.addObject(new EarthObject(200, 700), 100, -50);
        world.addObject(new EarthObject(300, 100), 1650, 450);
        world.addObject(new EarthObject(100, 300), 1750, 250);
        world.addObject(new LavaObject(200, 300), 1600, 250);
        world.addObject(new EarthObject(1000, 200), 900, 0);
        world.addObject(new EarthObject(800, 200), 400, -500);
        world.addObject(new EarthObject(200, 300), 700, -250);
        world.addObject(new EarthObject(300, 100), 850, 250);
        world.addObject(new EarthObject(300, 100), 1250, 150);
        world.addObject(new EarthObject(300, 100), 1550, -50);
        world.addObject(new EarthObject(300, 200), 2050, 300);
        world.addObject(new EarthObject(200, 300), 2100, 50);
        world.addObject(new EarthObject(900, 100), 1750, -150);
        world.addObject(new LavaObject(300, 100), 1850, -50);
        world.addObject(new LavaObject(100, 200), 1950, 100);
        world.addObject(new EarthObject(200, 500), 2100, 650);
        world.addObject(new EarthObject(1000, 200), 1500, 800);
        world.addObject(new EarthObject(200, 100), 1900, 650);
        world.addObject(new LavaObject(800, 100), 1400, 650);
        world.addObject(new EarthObject(200, 500), 700, 750);
        world.addObject(new EarthObject(200, 1000), 500, 1300);
        world.addObject(new EarthObject(1000, 200), 1100, 1700);
        world.addObject(new EarthObject(200, 500), 1700, 1550);
        world.addObject(new EarthObject(300, 500), 1050, 1250);
        world.addObject(new EarthObject(200, 300), 1300, 1050);
        world.addObject(new EarthObject(100, 100), 850, 1250);
        world.addObject(new EarthObject(100, 100), 650, 1450);
        world.addObject(new LavaObject(200, 100), 700, 1050);
        world.addObject(new LavaObject(100, 100), 750, 1250);
        world.addObject(new LavaObject(100, 100), 750, 1450);
        world.addObject(new LavaObject(200, 100), 700, 1550);
        world.addObject(new LavaObject(100, 300), 1550, 1450);
        world.addObject(new LavaObject(100, 300), 1250, 1350);
        world.addObject(new LavaObject(500, 200), 1650, 1000);
        world.addObject(new EarthObject(300, 500), 2050, 1150);
        world.addObject(new EarthObject(400, 100), 2000, 1750);
        world.addObject(new EarthObject(100, 300), 2150, 1550);
        world.addObject(new SpawnPoint(false), 1750, 50);
        world.addObject(new SpawnPoint(false), 850, 1150);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel3() {
        world.addObject(new EndGate(), 150, -750);
        world.addObject(new SpawnPoint(false), 750, -650);
        world.addObject(new LavaObject(200, 400), 100, 200);
        world.addObject(new LavaObject(200, 200), 400, 200);
        world.addObject(new LavaObject(200, 400), 800, 0);
        world.addObject(new LavaObject(600, 100), 600, -250);
        world.addObject(new LavaObject(100, 300), 150, -450);
        world.addObject(new LavaObject(300, 100), 350, -550);
        world.addObject(new LavaObject(100, 500), 50, -950);
        world.addObject(new LavaObject(200, 300), 400, -750);
        world.addObject(new LavaObject(300, 200), 750, -800);
        world.addObject(new LavaObject(100, 500), 1050, -750);
        world.addObject(new LavaObject(100, 200), 750, -1200);
        world.addObject(new LavaObject(400, 100), 500, -1250);
        world.addObject(new EarthObject(300, 100), 350, 350);
        world.addObject(new EarthObject(500, 200), 250, 500);
        world.addObject(new EarthObject(200, 700), -100, 250);
        world.addObject(new EarthObject(500, 100), 250, -50);
        world.addObject(new EarthObject(200, 100), 600, 150);
        world.addObject(new EarthObject(500, 200), 750, 300);
        world.addObject(new EarthObject(100, 100), 550, 450);
        world.addObject(new EarthObject(100, 500), 950, -50);
        world.addObject(new EarthObject(200, 300), 0, -250);
        world.addObject(new EarthObject(100, 300), 50, -550);
        world.addObject(new EarthObject(400, 300), 800, -450);
        world.addObject(new EarthObject(100, 800), -50, -800);
        world.addObject(new EarthObject(100, 200), 250, -700);
        world.addObject(new EarthObject(100, 200), 550, -900);
        world.addObject(new EarthObject(100, 200), 1050, -400);
        world.addObject(new EarthObject(100, 600), 1150, -700);
        world.addObject(new EarthObject(500, 100), 950, -1050);
        world.addObject(new EarthObject(300, 100), 950, -1150);
        world.addObject(new EarthObject(200, 100), 900, -1250);
        world.addObject(new EarthObject(1000, 100), 400, -1350);
        world.addObject(new EarthObject(400, 100), 100, -1250);
        world.addObject(new EarthObject(100, 100), 150, -650);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel4() {
        world.addObject(new EndGate(), 1350, -650);
        world.addObject(new SpawnPoint(false), 150, -250);
        world.addObject(new SpawnPoint(false), 750, 250);
        world.addObject(new LavaObject(500, 100), 250, 450);
        world.addObject(new LavaObject(100, 800), -50, 100);
        world.addObject(new LavaObject(500, 100), 150, -350);
        world.addObject(new LavaObject(200, 100), 300, -150);
        world.addObject(new LavaObject(300, 300), 650, -350);
        world.addObject(new LavaObject(100, 200), 650, 300);
        world.addObject(new LavaObject(100, 200), 1150, 300);
        world.addObject(new LavaObject(300, 200), 1050, 0);
        world.addObject(new LavaObject(100, 500), 950, -350);
        world.addObject(new LavaObject(200, 200), 1300, -400);
        world.addObject(new LavaObject(100, 300), 1350, -150);
        world.addObject(new LavaObject(100, 200), 1250, -700);
        world.addObject(new LavaObject(200, 400), 900, -800);
        world.addObject(new LavaObject(400, 200), 1000, -1100);
        world.addObject(new EarthObject(500, 100), 250, 550);
        world.addObject(new EarthObject(300, 100), 350, -50);
        world.addObject(new EarthObject(100, 700), 550, 250);
        world.addObject(new EarthObject(100, 500), 150, 50);
        world.addObject(new EarthObject(200, 100), -100, 550);
        world.addObject(new EarthObject(100, 900), -150, 50);
        world.addObject(new EarthObject(700, 100), 150, -450);
        world.addObject(new EarthObject(100, 100), 450, -350);
        world.addObject(new EarthObject(500, 100), 650, -550);
        world.addObject(new EarthObject(100, 600), 850, -200);
        world.addObject(new EarthObject(200, 200), 700, 500);
        world.addObject(new EarthObject(100, 100), 750, 350);
        world.addObject(new EarthObject(500, 200), 1050, 500);
        world.addObject(new EarthObject(200, 600), 1400, 300);
        world.addObject(new EarthObject(100, 200), 1250, 300);
        world.addObject(new EarthObject(100, 600), 1450, -300);
        world.addObject(new EarthObject(200, 100), 1300, -550);
        world.addObject(new EarthObject(100, 400), 1450, -800);
        world.addObject(new EarthObject(300, 200), 1350, -1100);
        world.addObject(new EarthObject(700, 100), 1150, -1250);
        world.addObject(new EarthObject(100, 700), 750, -950);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel5() {
        world.addObject(new EndGate(), 50, -50);
        world.addObject(new SpawnPoint(false), 250, -650);
        world.addObject(new LavaObject(100, 100), 350, 50);
        world.addObject(new LavaObject(100, 100), 350, -150);
        world.addObject(new LavaObject(100, 300), 150, -50);
        world.addObject(new LavaObject(300, 100), -50, -150);
        world.addObject(new LavaObject(300, 100), -50, 50);
        world.addObject(new LavaObject(100, 300), 950, -50);
        world.addObject(new LavaObject(100, 100), 850, -150);
        world.addObject(new LavaObject(500, 100), 1050, 450);
        world.addObject(new LavaObject(100, 300), 1250, 50);
        world.addObject(new LavaObject(100, 600), 1450, -100);
        world.addObject(new LavaObject(200, 200), 1500, 300);
        world.addObject(new LavaObject(100, 100), 1350, -350);
        world.addObject(new LavaObject(200, 200), 1100, -400);
        world.addObject(new LavaObject(500, 100), 1250, -750);
        world.addObject(new LavaObject(400, 200), 800, -800);
        world.addObject(new LavaObject(100, 100), 650, -650);
        world.addObject(new LavaObject(100, 200), 550, -300);
        world.addObject(new LavaObject(400, 100), 800, -350);
        world.addObject(new LavaObject(700, 200), 250, -800);
        world.addObject(new LavaObject(200, 200), -200, -500);
        world.addObject(new EarthObject(500, 200), 250, 400);
        world.addObject(new EarthObject(200, 200), 400, 200);
        world.addObject(new EarthObject(200, 200), 100, 200);
        world.addObject(new EarthObject(200, 200), 400, -300);
        world.addObject(new EarthObject(200, 200), 100, -300);
        world.addObject(new EarthObject(500, 200), 250, -500);
        world.addObject(new EarthObject(100, 100), 450, -150);
        world.addObject(new EarthObject(100, 100), 450, 50);
        world.addObject(new EarthObject(300, 100), 650, -150);
        world.addObject(new EarthObject(300, 100), 650, 50);
        world.addObject(new EarthObject(200, 500), 1100, -50);
        world.addObject(new EarthObject(400, 100), 800, -250);
        world.addObject(new EarthObject(200, 300), 700, 250);
        world.addObject(new EarthObject(200, 100), 700, 450);
        world.addObject(new EarthObject(600, 100), 1000, 550);
        world.addObject(new EarthObject(100, 100), 950, 150);
        world.addObject(new EarthObject(300, 200), 1450, 500);
        world.addObject(new EarthObject(200, 1000), 1700, 100);
        world.addObject(new EarthObject(100, 600), 1550, -100);
        world.addObject(new EarthObject(500, 300), 1550, -550);
        world.addObject(new EarthObject(200, 100), 1600, -750);
        world.addObject(new EarthObject(600, 100), 1300, -850);
        world.addObject(new EarthObject(500, 100), 850, -950);
        world.addObject(new EarthObject(800, 100), 200, -950);
        world.addObject(new EarthObject(100, 300), -150, -750);
        world.addObject(new EarthObject(100, 100), -250, -750);
        world.addObject(new EarthObject(200, 100), -300, -650);
        world.addObject(new EarthObject(200, 800), -400, -200);
        world.addObject(new EarthObject(300, 100), -150, 150);
        world.addObject(new EarthObject(100, 300), 550, 250);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel6() {
        world.addObject(new EndGate(), -950, 1150);
        world.addObject(new SpawnPoint(false), 450, 1250);
        world.addObject(new SpawnPoint(false), 240, 250);
        world.addObject(new SpawnPoint(false), -750, 1650);
        world.addObject(new SpawnPoint(false), 1050, 850);
        world.addObject(new LavaObject(100, 200), 150, 500);
        world.addObject(new LavaObject(100, 300), 350, 450);
        world.addObject(new LavaObject(300, 100), -150, 250);
        world.addObject(new LavaObject(100, 200), -250, 400);
        world.addObject(new LavaObject(200, 200), -300, 800);
        world.addObject(new LavaObject(300, 300), -550, 750);
        world.addObject(new LavaObject(100, 200), 50, 900);
        world.addObject(new LavaObject(500, 100), 450, 850);
        world.addObject(new LavaObject(300, 100), 550, 750);
        world.addObject(new LavaObject(300, 100), 650, 550);
        world.addObject(new LavaObject(500, 100), 550, 50);
        world.addObject(new LavaObject(100, 200), 850, 400);
        world.addObject(new LavaObject(100, 100), 850, 150);
        world.addObject(new LavaObject(500, 200), 250, -300);
        world.addObject(new LavaObject(200, 400), -200, 0);
        world.addObject(new LavaObject(200, 100), 400, 250);
        world.addObject(new LavaObject(200, 100), 700, 450);
        world.addObject(new LavaObject(500, 200), 750, 1000);
        world.addObject(new LavaObject(300, 100), 1050, 750);
        world.addObject(new LavaObject(200, 500), 1600, 950);
        world.addObject(new LavaObject(400, 200), 1200, 1100);
        world.addObject(new LavaObject(400, 100), 200, 1050);
        world.addObject(new LavaObject(200, 200), 1300, 1400);
        world.addObject(new LavaObject(500, 100), 950, 1450);
        world.addObject(new LavaObject(200, 100), 700, 1150);
        world.addObject(new LavaObject(100, 100), 750, 1250);
        world.addObject(new LavaObject(100, 500), -850, 650);
        world.addObject(new LavaObject(400, 200), -600, 1200);
        world.addObject(new LavaObject(200, 100), -100, 1050);
        world.addObject(new LavaObject(200, 100), -100, 1350);
        world.addObject(new LavaObject(100, 100), -350, 1450);
        world.addObject(new LavaObject(400, 100), -400, 1750);
        world.addObject(new LavaObject(200, 100), -500, 1550);
        world.addObject(new LavaObject(300, 100), -950, 1750);
        world.addObject(new LavaObject(200, 100), -900, 1450);
        world.addObject(new LavaObject(200, 500), -1100, 1250);
        world.addObject(new LavaObject(300, 200), -1450, 1500);
        world.addObject(new LavaObject(200, 200), -1300, 1800);
        world.addObject(new LavaObject(100, 100), -850, 1550);
        world.addObject(new LavaObject(200, 200), -1300, 1100);
        world.addObject(new LavaObject(300, 200), -1250, 800);
        world.addObject(new LavaObject(100, 500), -1550, 950);
        world.addObject(new EarthObject(100, 100), 250, 450);
        world.addObject(new EarthObject(100, 100), -150, 350);
        world.addObject(new EarthObject(100, 100), -50, 850);
        world.addObject(new EarthObject(100, 100), 350, 750);
        world.addObject(new EarthObject(100, 300), 850, 650);
        world.addObject(new EarthObject(100, 100), 850, 50);
        world.addObject(new EarthObject(200, 100), 900, 250);
        world.addObject(new EarthObject(200, 200), 400, -100);
        world.addObject(new EarthObject(300, 200), -150, -300);
        world.addObject(new EarthObject(200, 200), 1400, 800);
        world.addObject(new EarthObject(100, 100), 1250, 750);
        world.addObject(new EarthObject(600, 100), 1200, 650);
        world.addObject(new EarthObject(100, 100), 1050, 950);
        world.addObject(new EarthObject(300, 100), 1650, 650);
        world.addObject(new EarthObject(100, 500), 1750, 950);
        world.addObject(new EarthObject(300, 300), 1650, 1350);
        world.addObject(new EarthObject(100, 100), 1450, 1450);
        world.addObject(new EarthObject(200, 200), 900, 1200);
        world.addObject(new EarthObject(300, 200), 450, 1400);
        world.addObject(new EarthObject(100, 100), 650, 1450);
        world.addObject(new EarthObject(600, 200), -600, 300);
        world.addObject(new EarthObject(500, 100), -150, 1150);
        world.addObject(new EarthObject(100, 300), -850, 1050);
        world.addObject(new EarthObject(500, 200), 50, 1500);
        world.addObject(new EarthObject(100, 100), 350, 1550);
        world.addObject(new EarthObject(200, 200), -500, 1400);
        world.addObject(new EarthObject(100, 300), -150, 1750);
        world.addObject(new EarthObject(100, 200), -50, 1700);
        world.addObject(new EarthObject(100, 100), 50, 1650);
        world.addObject(new EarthObject(500, 100), -450, 1850);
        world.addObject(new EarthObject(200, 200), -900, 1300);
        world.addObject(new EarthObject(200, 300), -700, 1450);
        world.addObject(new EarthObject(200, 100), -700, 1750);
        world.addObject(new EarthObject(100, 100), -1550, 1650);
        world.addObject(new EarthObject(100, 100), -1150, 1750);
        world.addObject(new EarthObject(200, 100), -1500, 1750);
        world.addObject(new EarthObject(500, 200), -950, 1900);
        world.addObject(new EarthObject(200, 100), -1300, 1950);
        world.addObject(new EarthObject(200, 200), -1500, 1900);
        world.addObject(new EarthObject(100, 200), -1550, 1300);
        world.addObject(new EarthObject(200, 300), -1000, 750);
        world.addObject(new EarthObject(600, 100), -1400, 650);
        world.addObject(new EarthObject(100, 1300), -1650, 1350);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel7() {
        world.addObject(new EndGate(), 250, -850);
        world.addObject(new SpawnPoint(false), 250, 244);
        world.addObject(new SpawnPoint(false), -650, 650);
        world.addObject(new SpawnPoint(false), 1150, 650);
        world.addObject(new SpawnPoint(false), 1650, -250);
        world.addObject(new SpawnPoint(false), 950, -350);
        world.addObject(new SpawnPoint(false), -450, -350);
        world.addObject(new SpawnPoint(false), -1150, -250);
        world.addObject(new LavaObject(100, 300), 350, 50);
        world.addObject(new LavaObject(100, 300), 150, 50);
        world.addObject(new LavaObject(100, 300), 150, 550);
        world.addObject(new LavaObject(100, 300), 350, 550);
        world.addObject(new LavaObject(300, 100), -50, 150);
        world.addObject(new LavaObject(300, 100), 550, 150);
        world.addObject(new LavaObject(100, 300), -150, -50);
        world.addObject(new LavaObject(100, 300), 650, -50);
        world.addObject(new LavaObject(100, 300), -150, 550);
        world.addObject(new LavaObject(100, 300), 650, 550);
        world.addObject(new LavaObject(200, 200), 0, 700);
        world.addObject(new LavaObject(200, 200), 500, 700);
        world.addObject(new LavaObject(200, 100), 400, -250);
        world.addObject(new LavaObject(200, 100), 100, -250);
        world.addObject(new LavaObject(100, 400), 50, -500);
        world.addObject(new LavaObject(100, 400), 450, -500);
        world.addObject(new LavaObject(300, 100), 250, 1450);
        world.addObject(new LavaObject(100, 400), 50, 1300);
        world.addObject(new LavaObject(100, 400), 450, 1300);
        world.addObject(new LavaObject(100, 100), 150, 1150);
        world.addObject(new LavaObject(100, 100), 350, 1150);
        world.addObject(new LavaObject(200, 400), -500, 800);
        world.addObject(new LavaObject(400, 200), -400, 1100);
        world.addObject(new LavaObject(400, 200), 900, 1100);
        world.addObject(new LavaObject(200, 400), 1000, 800);
        world.addObject(new LavaObject(500, 100), 850, 350);
        world.addObject(new LavaObject(300, 200), 1350, 400);
        world.addObject(new LavaObject(300, 300), 1150, 50);
        world.addObject(new LavaObject(200, 500), 1600, 250);
        world.addObject(new LavaObject(500, 100), -350, 350);
        world.addObject(new LavaObject(300, 300), -650, 50);
        world.addObject(new LavaObject(300, 200), -850, 400);
        world.addObject(new LavaObject(200, 500), -1100, 250);
        world.addObject(new LavaObject(300, 200), -850, 800);
        world.addObject(new LavaObject(200, 200), -1200, 800);
        world.addObject(new LavaObject(100, 500), -1350, 650);
        world.addObject(new LavaObject(300, 200), -1250, 1100);
        world.addObject(new LavaObject(300, 200), -850, 1100);
        world.addObject(new LavaObject(300, 200), 1350, 800);
        world.addObject(new LavaObject(200, 200), 1700, 800);
        world.addObject(new LavaObject(100, 500), 1850, 650);
        world.addObject(new LavaObject(300, 200), 1350, 1100);
        world.addObject(new LavaObject(300, 200), 1750, 1100);
        world.addObject(new LavaObject(100, 1000), -1650, 500);
        world.addObject(new LavaObject(200, 200), -1500, 100);
        world.addObject(new LavaObject(100, 200), -1450, 800);
        world.addObject(new LavaObject(100, 100), -1550, 250);
        world.addObject(new LavaObject(100, 200), 1950, 800);
        world.addObject(new LavaObject(100, 1000), 2150, 500);
        world.addObject(new LavaObject(200, 200), 2000, 100);
        world.addObject(new LavaObject(100, 100), 2050, 250);
        world.addObject(new LavaObject(200, 200), 1900, -300);
        world.addObject(new LavaObject(100, 100), 1750, -350);
        world.addObject(new LavaObject(200, 200), -1400, -300);
        world.addObject(new LavaObject(100, 100), -1250, -350);
        world.addObject(new LavaObject(300, 300), 1250, -350);
        world.addObject(new LavaObject(200, 200), 1700, -600);
        world.addObject(new LavaObject(300, 300), -750, -350);
        world.addObject(new LavaObject(200, 200), -1200, -600);
        world.addObject(new LavaObject(400, 100), 1400, -750);
        world.addObject(new LavaObject(400, 100), -900, -750);
        world.addObject(new LavaObject(300, 200), -450, -800);
        world.addObject(new LavaObject(100, 100), -550, -250);
        world.addObject(new LavaObject(100, 200), -450, -600);
        world.addObject(new LavaObject(100, 100), -350, -650);
        world.addObject(new LavaObject(300, 200), 950, -800);
        world.addObject(new LavaObject(100, 100), 850, -650);
        world.addObject(new LavaObject(100, 200), 950, -600);
        world.addObject(new LavaObject(100, 100), 1050, -250);
        world.addObject(new LavaObject(100, 400), -350, -1100);
        world.addObject(new LavaObject(100, 400), 850, -1100);
        world.addObject(new LavaObject(500, 100), 550, -1250);
        world.addObject(new LavaObject(500, 100), -50, -1250);
        world.addObject(new LavaObject(200, 200), 600, -1100);
        world.addObject(new LavaObject(100, 100), 350, -950);
        world.addObject(new LavaObject(100, 100), 350, -1150);
        world.addObject(new LavaObject(100, 100), 150, -1150);
        world.addObject(new LavaObject(100, 100), 150, -950);
        world.addObject(new LavaObject(200, 200), -100, -1100);
        world.addObject(new EarthObject(200, 200), 500, 0);
        world.addObject(new EarthObject(200, 200), 500, 500);
        world.addObject(new EarthObject(200, 200), 0, 500);
        world.addObject(new EarthObject(200, 200), 0, 0);
        world.addObject(new EarthObject(300, 100), 450, -150);
        world.addObject(new EarthObject(300, 100), 50, -150);
        world.addObject(new EarthObject(200, 700), -100, -550);
        world.addObject(new EarthObject(200, 700), 600, -550);
        world.addObject(new EarthObject(500, 100), 250, -750);
        world.addObject(new EarthObject(200, 100), 100, -850);
        world.addObject(new EarthObject(200, 100), 400, -850);
        world.addObject(new EarthObject(300, 200), 550, 1000);
        world.addObject(new EarthObject(300, 200), -50, 1000);
        world.addObject(new EarthObject(100, 100), 150, 1050);
        world.addObject(new EarthObject(100, 100), 350, 1050);
        world.addObject(new EarthObject(200, 500), -100, 1350);
        world.addObject(new EarthObject(200, 500), 600, 1350);
        world.addObject(new EarthObject(500, 100), 250, 1550);
        world.addObject(new EarthObject(100, 100), 150, 1350);
        world.addObject(new EarthObject(100, 100), 350, 1350);
        world.addObject(new EarthObject(500, 100), -450, 1250);
        world.addObject(new EarthObject(100, 500), -650, 950);
        world.addObject(new EarthObject(500, 100), 950, 1250);
        world.addObject(new EarthObject(100, 500), 1150, 950);
        world.addObject(new EarthObject(300, 200), 850, 100);
        world.addObject(new EarthObject(200, 200), 1400, 100);
        world.addObject(new EarthObject(300, 200), -350, 100);
        world.addObject(new EarthObject(200, 200), -900, 100);
        world.addObject(new EarthObject(100, 700), -1250, 250);
        world.addObject(new EarthObject(400, 200), -1000, -100);
        world.addObject(new EarthObject(300, 100), -650, -150);
        world.addObject(new EarthObject(300, 300), -350, -150);
        world.addObject(new EarthObject(200, 100), -300, -350);
        world.addObject(new EarthObject(100, 100), -250, -450);
        world.addObject(new EarthObject(500, 100), -950, 550);
        world.addObject(new EarthObject(100, 700), 1750, 250);
        world.addObject(new EarthObject(400, 200), 1500, -100);
        world.addObject(new EarthObject(300, 100), 1150, -150);
        world.addObject(new EarthObject(300, 300), 850, -150);
        world.addObject(new EarthObject(200, 100), 800, -350);
        world.addObject(new EarthObject(100, 100), 750, -450);
        world.addObject(new EarthObject(500, 100), 1450, 550);
        world.addObject(new EarthObject(700, 100), -1050, 1250);
        world.addObject(new EarthObject(700, 100), 1550, 1250);
        world.addObject(new EarthObject(300, 300), -1550, 1150);
        world.addObject(new EarthObject(200, 200), -1500, -100);
        world.addObject(new EarthObject(300, 300), 2050, 1150);
        world.addObject(new EarthObject(200, 200), 2000, -100);
        world.addObject(new EarthObject(200, 100), 2200, -50);
        world.addObject(new EarthObject(100, 1300), 2250, 650);
        world.addObject(new EarthObject(100, 300), 2050, -350);
        world.addObject(new EarthObject(300, 100), 1850, -450);
        world.addObject(new EarthObject(200, 100), -1700, -50);
        world.addObject(new EarthObject(100, 1300), -1750, 650);
        world.addObject(new EarthObject(100, 300), -1550, -350);
        world.addObject(new EarthObject(300, 100), -1350, -450);
        world.addObject(new EarthObject(100, 200), 1650, -400);
        world.addObject(new EarthObject(100, 300), 1850, -650);
        world.addObject(new EarthObject(100, 200), 1950, -600);
        world.addObject(new EarthObject(100, 100), 2050, -550);
        world.addObject(new EarthObject(200, 100), 1700, -750);
        world.addObject(new EarthObject(100, 300), -1350, -650);
        world.addObject(new EarthObject(100, 200), -1450, -600);
        world.addObject(new EarthObject(100, 100), -1550, -550);
        world.addObject(new EarthObject(100, 200), -1150, -400);
        world.addObject(new EarthObject(600, 100), 1500, -850);
        world.addObject(new EarthObject(200, 100), -1200, -750);
        world.addObject(new EarthObject(600, 100), -1000, -850);
        world.addObject(new EarthObject(100, 200), -650, -800);
        world.addObject(new EarthObject(100, 200), 1150, -800);
        world.addObject(new EarthObject(400, 100), 1100, -950);
        world.addObject(new EarthObject(200, 300), 1000, -1150);
        world.addObject(new EarthObject(400, 100), -600, -950);
        world.addObject(new EarthObject(200, 300), -500, -1150);
        world.addObject(new EarthObject(100, 100), 250, -1250);
        world.addObject(new EarthObject(1500, 100), 250, -1350);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel8() {
        world.addObject(new EndGate(), 2650, 2450);
        world.addObject(new SpawnPoint(false), 550, 1350);
        world.addObject(new SpawnPoint(false), 1350, 1650);
        world.addObject(new SpawnPoint(false), 250, 250);
        world.addObject(new SpawnPoint(false), 2450, 2950);
        world.addObject(new LavaObject(500, 200), 250, 600);
        world.addObject(new LavaObject(200, 300), 500, 150);
        world.addObject(new LavaObject(200, 500), -100, 450);
        world.addObject(new LavaObject(500, 200), 350, -100);
        world.addObject(new LavaObject(300, 400), -50, 0);
        world.addObject(new LavaObject(300, 200), 750, 200);
        world.addObject(new LavaObject(200, 600), 1000, 400);
        world.addObject(new LavaObject(300, 200), 750, 600);
        world.addObject(new LavaObject(100, 300), 450, 850);
        world.addObject(new LavaObject(300, 100), 650, 950);
        world.addObject(new LavaObject(100, 500), 1050, 950);
        world.addObject(new LavaObject(500, 200), 850, 1300);
        world.addObject(new LavaObject(200, 200), 300, 900);
        world.addObject(new LavaObject(100, 400), 250, 1200);
        world.addObject(new LavaObject(200, 200), 400, 1300);
        world.addObject(new LavaObject(100, 600), 250, 1700);
        world.addObject(new LavaObject(1000, 100), 700, 2050);
        world.addObject(new LavaObject(200, 300), 800, 1550);
        world.addObject(new LavaObject(400, 200), 700, 1800);
        world.addObject(new LavaObject(300, 200), 1150, 1700);
        world.addObject(new LavaObject(100, 300), 1250, 1950);
        world.addObject(new LavaObject(500, 200), 1350, 1300);
        world.addObject(new LavaObject(200, 500), 1700, 1450);
        world.addObject(new LavaObject(200, 100), 1500, 1650);
        world.addObject(new LavaObject(200, 200), 1400, 2000);
        world.addObject(new LavaObject(100, 200), 1750, 1800);
        world.addObject(new LavaObject(500, 200), 1450, 2200);
        world.addObject(new LavaObject(300, 100), 1950, 1850);
        world.addObject(new LavaObject(200, 400), 2000, 2100);
        world.addObject(new LavaObject(100, 300), 1950, 2450);
        world.addObject(new LavaObject(500, 100), 1650, 2550);
        world.addObject(new LavaObject(200, 800), 1100, 2500);
        world.addObject(new LavaObject(500, 100), 1450, 2850);
        world.addObject(new LavaObject(100, 300), 1950, 2750);
        world.addObject(new LavaObject(100, 300), 1650, 3050);
        world.addObject(new LavaObject(500, 100), 1950, 3150);
        world.addObject(new LavaObject(200, 300), 2300, 3050);
        world.addObject(new LavaObject(500, 200), 2250, 2600);
        world.addObject(new LavaObject(100, 500), 2550, 2750);
        world.addObject(new LavaObject(500, 100), 2450, 3250);
        world.addObject(new LavaObject(200, 200), 2800, 3300);
        world.addObject(new LavaObject(200, 400), 3000, 3200);
        world.addObject(new LavaObject(500, 200), 3350, 3100);
        world.addObject(new LavaObject(200, 500), 3500, 2750);
        world.addObject(new LavaObject(100, 200), 3450, 2400);
        world.addObject(new LavaObject(100, 100), 3550, 2450);
        world.addObject(new LavaObject(100, 200), 3350, 2300);
        world.addObject(new LavaObject(100, 200), 3250, 2200);
        world.addObject(new LavaObject(100, 200), 3150, 2100);
        world.addObject(new LavaObject(500, 100), 2850, 2050);
        world.addObject(new LavaObject(200, 500), 2500, 2250);
        world.addObject(new LavaObject(500, 300), 2850, 2650);
        world.addObject(new LavaObject(300, 100), 2850, 2450);
        world.addObject(new LavaObject(100, 100), 2850, 2350);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel9() {
        world.addObject(new EndGate(), -1850, -550);
        world.addObject(new SpawnPoint(false), 150, 1150);
        world.addObject(new SpawnPoint(false), 1050, 250);
        world.addObject(new SpawnPoint(false), 1050, -1050);
        world.addObject(new SpawnPoint(false), -650, -1050);
        world.addObject(new SpawnPoint(false), 50, -1050);
        world.addObject(new SpawnPoint(false), -750, -50);
        world.addObject(new LavaObject(400, 100), 400, 750);
        world.addObject(new LavaObject(100, 300), 550, 950);
        world.addObject(new LavaObject(200, 100), 700, 1250);
        world.addObject(new LavaObject(100, 100), 750, 1150);
        world.addObject(new LavaObject(400, 100), 300, 1050);
        world.addObject(new LavaObject(300, 100), 350, 1250);
        world.addObject(new LavaObject(200, 100), 800, 250);
        world.addObject(new LavaObject(100, 200), 650, 0);
        world.addObject(new LavaObject(100, 200), 1050, 100);
        world.addObject(new LavaObject(300, 100), 950, -50);
        world.addObject(new LavaObject(100, 100), 850, 50);
        world.addObject(new LavaObject(200, 100), 1000, -250);
        world.addObject(new LavaObject(200, 100), 700, -250);
        world.addObject(new LavaObject(400, 500), 0, -350);
        world.addObject(new LavaObject(700, 200), 150, -700);
        world.addObject(new LavaObject(1000, 200), 600, -1200);
        world.addObject(new LavaObject(100, 200), -50, -1400);
        world.addObject(new LavaObject(600, 100), 200, -1550);
        world.addObject(new LavaObject(100, 200), 1350, -1200);
        world.addObject(new LavaObject(300, 200), 850, -1400);
        world.addObject(new LavaObject(500, 100), 850, -1650);
        world.addObject(new LavaObject(100, 100), 1350, -1650);
        world.addObject(new LavaObject(200, 200), 1300, -1400);
        world.addObject(new LavaObject(200, 200), 500, -300);
        world.addObject(new LavaObject(100, 100), 450, -150);
        world.addObject(new LavaObject(200, 100), -400, 250);
        world.addObject(new LavaObject(100, 300), -150, 50);
        world.addObject(new LavaObject(100, 300), -350, 50);
        world.addObject(new LavaObject(500, 200), -450, -500);
        world.addObject(new LavaObject(200, 200), -400, -300);
        world.addObject(new LavaObject(100, 100), -650, -150);
        world.addObject(new LavaObject(300, 100), -950, -150);
        world.addObject(new LavaObject(300, 200), -850, -500);
        world.addObject(new LavaObject(300, 200), -950, 100);
        world.addObject(new LavaObject(200, 200), -600, 300);
        world.addObject(new LavaObject(200, 300), -1200, -750);
        world.addObject(new LavaObject(200, 200), -900, -800);
        world.addObject(new LavaObject(200, 100), -500, -950);
        world.addObject(new LavaObject(100, 300), -250, -1050);
        world.addObject(new LavaObject(300, 100), -550, -1150);
        world.addObject(new LavaObject(100, 200), -850, -1400);
        world.addObject(new LavaObject(200, 300), -600, -1350);
        world.addObject(new LavaObject(500, 200), -750, 500);
        world.addObject(new LavaObject(300, 200), -1250, 400);
        world.addObject(new LavaObject(100, 100), -1450, -150);
        world.addObject(new LavaObject(300, 100), -1450, -250);
        world.addObject(new LavaObject(200, 100), -1500, 450);
        world.addObject(new LavaObject(200, 200), -1700, 200);
        world.addObject(new LavaObject(300, 200), -1850, -200);
        world.addObject(new LavaObject(200, 300), -1700, -450);
        world.addObject(new EarthObject(300, 300), 450, 50);
        world.addObject(new EarthObject(300, 300), 50, 50);
        world.addObject(new EarthObject(400, 300), 500, 450);
        world.addObject(new EarthObject(300, 500), 50, 550);
        world.addObject(new EarthObject(200, 800), 800, 700);
        world.addObject(new EarthObject(600, 200), 200, 900);
        world.addObject(new EarthObject(100, 100), 550, 1250);
        world.addObject(new EarthObject(100, 300), 850, 1250);
        world.addObject(new EarthObject(300, 100), 650, 1350);
        world.addObject(new EarthObject(200, 500), 0, 1250);
        world.addObject(new EarthObject(400, 200), 300, 1400);
        world.addObject(new EarthObject(400, 100), 700, 1450);
        world.addObject(new EarthObject(100, 100), 150, 1250);
        world.addObject(new EarthObject(300, 200), 1050, 400);
        world.addObject(new EarthObject(200, 800), 1300, 100);
        world.addObject(new EarthObject(100, 100), 950, 50);
        world.addObject(new EarthObject(500, 200), 1150, -400);
        world.addObject(new EarthObject(200, 500), 1000, -750);
        world.addObject(new EarthObject(200, 800), 700, -700);
        world.addObject(new EarthObject(500, 200), 250, -900);
        world.addObject(new EarthObject(200, 500), -100, -1050);
        world.addObject(new EarthObject(100, 300), -150, -1450);
        world.addObject(new EarthObject(800, 100), 200, -1650);
        world.addObject(new EarthObject(300, 200), 1250, -900);
        world.addObject(new EarthObject(200, 500), 1500, -1050);
        world.addObject(new EarthObject(600, 100), 800, -1750);
        world.addObject(new EarthObject(200, 200), 1200, -1700);
        world.addObject(new EarthObject(200, 400), 1500, -1500);
        world.addObject(new EarthObject(300, 100), 1450, -1750);
        world.addObject(new EarthObject(200, 100), 600, -150);
        world.addObject(new EarthObject(400, 200), -300, 400);
        world.addObject(new EarthObject(300, 200), -550, 100);
        world.addObject(new EarthObject(200, 200), -600, -300);
        world.addObject(new EarthObject(300, 100), -1050, -50);
        world.addObject(new EarthObject(100, 500), -1150, -350);
        world.addObject(new EarthObject(300, 200), -1350, -500);
        world.addObject(new EarthObject(200, 500), -1400, -850);
        world.addObject(new EarthObject(500, 200), -1050, -1000);
        world.addObject(new EarthObject(300, 200), -350, -700);
        world.addObject(new EarthObject(200, 300), -700, -850);
        world.addObject(new EarthObject(100, 100), -250, -850);
        world.addObject(new EarthObject(200, 200), -900, -1200);
        world.addObject(new EarthObject(100, 100), -350, -1150);
        world.addObject(new EarthObject(100, 200), -950, -1400);
        world.addObject(new EarthObject(500, 200), -750, -1600);
        world.addObject(new EarthObject(200, 500), -400, -1450);
        world.addObject(new EarthObject(100, 500), -250, -1450);
        world.addObject(new EarthObject(200, 200), -400, 600);
        world.addObject(new EarthObject(600, 100), -800, 650);
        world.addObject(new EarthObject(100, 200), -1050, 500);
        world.addObject(new EarthObject(300, 200), -1250, 100);
        world.addObject(new EarthObject(100, 100), -1250, -50);
        world.addObject(new EarthObject(200, 100), -1500, 150);
        world.addObject(new EarthObject(500, 200), -1350, 600);
        world.addObject(new EarthObject(400, 300), -1800, 550);
        world.addObject(new EarthObject(100, 500), -1950, 150);
        world.addObject(new EarthObject(100, 200), -1650, -200);
        world.addObject(new EarthObject(100, 100), -1550, -150);
        world.addObject(new EarthObject(500, 200), -1750, -800);
        world.addObject(new EarthObject(200, 200), -1900, -400);
        world.addObject(new EarthObject(100, 200), -1950, -600);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
    
    public void buildLevel10() {
        world.addObject(new EndGate(), -550, 50);
        world.addObject(new SpawnPoint(false), -50, -750);
        world.addObject(new SpawnPoint(false), -350, 350);
        world.addObject(new SpawnPoint(false), -550, -1750);
        world.addObject(new LavaObject(200, 300), 100, 250);
        world.addObject(new LavaObject(100, 300), 450, 150);
        world.addObject(new LavaObject(400, 200), 300, -100);
        world.addObject(new LavaObject(300, 200), 50, -500);
        world.addObject(new LavaObject(300, 100), 250, -350);
        world.addObject(new LavaObject(200, 300), -100, -250);
        world.addObject(new LavaObject(100, 100), 550, -350);
        world.addObject(new LavaObject(100, 300), 350, -650);
        world.addObject(new LavaObject(200, 100), 500, -550);
        world.addObject(new LavaObject(400, 200), 200, -900);
        world.addObject(new LavaObject(200, 200), -200, -900);
        world.addObject(new LavaObject(300, 200), -50, -1400);
        world.addObject(new LavaObject(500, 100), -650, -1050);
        world.addObject(new LavaObject(100, 400), -1150, -1000);
        world.addObject(new LavaObject(300, 200), -950, -800);
        world.addObject(new LavaObject(100, 500), -550, -750);
        world.addObject(new LavaObject(200, 200), -600, -400);
        world.addObject(new LavaObject(200, 500), -900, -450);
        world.addObject(new LavaObject(200, 200), -1000, -100);
        world.addObject(new LavaObject(300, 200), -750, 200);
        world.addObject(new LavaObject(500, 100), -650, -50);
        world.addObject(new LavaObject(100, 100), -450, 50);
        world.addObject(new LavaObject(200, 100), -500, 150);
        world.addObject(new LavaObject(100, 300), -450, 450);
        world.addObject(new LavaObject(600, 100), -800, 550);
        world.addObject(new LavaObject(100, 500), -1050, 250);
        world.addObject(new EarthObject(300, 200), 350, 400);
        world.addObject(new EarthObject(300, 100), 50, 450);
        world.addObject(new EarthObject(100, 500), -50, 150);
        world.addObject(new EarthObject(200, 700), 600, 150);
        world.addObject(new EarthObject(200, 200), -200, 0);
        world.addObject(new EarthObject(100, 100), -150, 150);
        world.addObject(new EarthObject(100, 300), -250, -250);
        world.addObject(new EarthObject(200, 400), -200, -600);
        world.addObject(new EarthObject(100, 500), 650, -450);
        world.addObject(new EarthObject(200, 100), 500, -650);
        world.addObject(new EarthObject(100, 100), -50, -650);
        world.addObject(new EarthObject(200, 400), -400, -800);
        world.addObject(new EarthObject(300, 100), -250, -1050);
        world.addObject(new EarthObject(300, 100), 150, -1050);
        world.addObject(new EarthObject(200, 700), -400, -1450);
        world.addObject(new EarthObject(200, 700), 300, -1450);
        world.addObject(new EarthObject(200, 300), -200, -1750);
        world.addObject(new EarthObject(200, 300), 100, -1750);
        world.addObject(new EarthObject(200, 300), 100, -2050);
        world.addObject(new EarthObject(600, 200), -100, -2300);
        world.addObject(new EarthObject(100, 300), -450, -2250);
        world.addObject(new EarthObject(100, 400), -550, -2200);
        world.addObject(new EarthObject(100, 500), -650, -2150);
        world.addObject(new EarthObject(200, 100), -700, -1850);
        world.addObject(new EarthObject(200, 100), -800, -1750);
        world.addObject(new EarthObject(200, 500), -900, -1450);
        world.addObject(new EarthObject(100, 100), -1050, -1450);
        world.addObject(new EarthObject(200, 100), -1100, -1350);
        world.addObject(new EarthObject(300, 100), -1150, -1250);
        world.addObject(new EarthObject(200, 400), -1300, -1000);
        world.addObject(new EarthObject(300, 200), -250, 500);
        world.addObject(new EarthObject(300, 100), 50, 550);
        world.addObject(new EarthObject(500, 200), -450, 700);
        world.addObject(new EarthObject(200, 100), -1200, -750);
        world.addObject(new EarthObject(200, 500), -1100, -450);
        world.addObject(new EarthObject(100, 900), -1150, 250);
        world.addObject(new EarthObject(400, 100), -900, 650);
        world.addObject(new EarthObject(100, 200), -550, -1600);
        world.addObject(new EarthObject(100, 100), -650, -1550);
        world.addObject(new SpawnPoint(true), world.getWidth()/2, world.getHeight()/2);
        world.addObject(new Textur(), 250, 250);
        Hero hero = new Hero();
        world.addObject(hero, world.getWidth()/2, world.getHeight()/2);
    }
}