import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * A MessageBox is a kind of textfield that is shonw in your levels if you want to tell the player something.
 * 
 * If you add a messagebox to your level it'll be printed with the blue print of the leve.
 * 
 * You can use every color, every text and every font size you want. The default colors are black letters on a transparent background.
 * 
 * @author Gevater_Tod4711
 * @version 1.0
 */
public class MessageBox extends Actor
{
    private String text;
    
    private int fontSize;
    
    private Color textColor;
    private Color backgroundColor;
    
    /**
     * Creates a MessageBox with the given text and font size.
     * The text will be black letters on a transparent background.
     * 
     * @param text
     *      The text you want to get printed on the screen.
     * 
     * @param fontSize
     *      The font size of the text.
     */
    public MessageBox(String text, int fontSize) {
        this(text, fontSize, Color.black, new Color(0, 0, 0, 0));
    }
    /**
     * Creates a MessageBox with the given text and font size.
     * The text will be the chosen color for the letters and a transparent background.
     * 
     * @param text
     *      The text you want to get printed on the screen.
     * 
     * @param fontSize
     *      The font size of the text.
     * 
     * @param textColor
     *      The color of the letters.
     */
    public MessageBox(String text, int fontSize, Color textColor) {
        this(text, fontSize, textColor, new Color(0, 0, 0, 0));
    }
    /**
     * Creates a MessageBox with the given text and font size.
     * The text will be chosen text- and background color.
     * 
     * @param text
     *      The text you want to get printed on the screen.
     * 
     * @param fontSize
     *      The font size of the text.
     *      
     * @param textColor
     *      The color of the letters.
     * 
     * @param backgroundColor
     *      The background color of the messagebox.
     */
    public MessageBox(String text, int fontSize, Color textColor, Color backgroundColor) {
        this.text = text;
        this.fontSize = fontSize;
        this.textColor = textColor;
        this.backgroundColor = backgroundColor;
        updateImage();
    }
    
    public void updateImage() {
        setImage(new GreenfootImage(text, fontSize, textColor, backgroundColor));
    }
    
    public String getText() {
        return text;
    }
    public String getTextAsString() {
        String temp = "\"" + text + "\"";
        temp = temp.replaceAll("\n", "\\\\n");
        return temp;
    }
    public void setText(String text) {
        this.text = text;
        updateImage();
    }
    
    public int getFontSize() {
        return fontSize;
    }
    public void setFontSize(int fontSize) {
        this.fontSize = fontSize;
        updateImage();
    }
    
    public Color getTextColor() {
        return textColor;
    }
    public void setTextColor(Color textColor) {
        this.textColor = textColor;
        updateImage();
    }
    
    public Color getBackgroundColor() {
        return backgroundColor;
    }
    public void setBackgroundColor(Color backgroundColor) {
        this.backgroundColor = backgroundColor;
        updateImage();
    }
}