import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * Write a description of class NumberField here.
 * 
 * @author Gevater_Tod4711
 * @version 1.2
 */
public class NumberField extends Menu
{
    private boolean active = false;
    private boolean cursorActive = false;
    private boolean edgeValues = false;
    
    private static int activeNumberField = 1;
    
    private int numberFieldNumber;
    private int textFontSize;
    private int maximumValue;
    private int minimumValue;
    
    private long cursorTime = System.currentTimeMillis();
    
    private String input = "";
    private String text = "";
    
    private Color bgColor = Color.white;
    private Color textColor = Color.black;
    
    private Arrow_Button upButton;
    private Arrow_Button downButton;
    
    /**
     * Creates a new NumberField of a default size of 250 x 50 with black letters on white background.
     */
    public NumberField() throws IllegalArgumentException {
        this(250, 50, Color.white, Color.black, 0, false, 0, 0);
    }
    
    /**
     * Creates a new NumberField of a default size of 250 x 50 with black letters on white background with the given edge values.
     * 
     * @param edgeValues
     *      True if there should be edge values.
     * 
     * @param maximumValue
     *      The maximum value the NumberField can reach.
     * 
     * @param minimumValue
     *      The minimum value the NumberField can reach.
     */
    public NumberField(boolean edgeValues, int minimumValue, int maximumValue) throws IllegalArgumentException {
        this(250, 50, Color.white, Color.black, 0, edgeValues, minimumValue, maximumValue);
    }
    
    /**
     * Creates a new NumberField with a default size of 250 x 50 with black letters on white background and a starting text.
     * 
     * @param edgeValues
     *      True if there should be edge values.
     * 
     * @param maximumValue
     *      The maximum value the NumberField can reach.
     * 
     * @param minimumValue
     *      The minimum value the NumberField can reach.
     * 
     * @param number
     *      The number that is shown directly.
     */
    public NumberField(boolean edgeValues, int minimumValue, int maximumValue, int number) throws IllegalArgumentException {
        this(250, 50, Color.white, Color.black, number, edgeValues, minimumValue, maximumValue);
    }
    
    /**
     * Creates a new NumberField with a default size of 250 x 50 with black letters on white background and a starting text.
     * 
     * @param number
     *      The number that is shown directly.
     */
    public NumberField(int number) throws IllegalArgumentException {
        this(250, 50, Color.white, Color.black, number, false, 0, 0);
    }
    
    /**
     * Creates a new NumberField of the given size with black letters on white background.
     * 
     * @param width
     *      The NumberFields width (which has to be greater than 50).
     * 
     * @param height
     *      The NumberFields height (which has to be greater than 20).
     */
    public NumberField(int width, int height) throws IllegalArgumentException {
        this(width, height, Color.white, Color.black, 0, false, 0, 0);
    }
    
    /**
     * Creates a new NumberField of the given size with black letters on white background.
     * 
     * @param width
     *      The NumberFields width (which has to be greater than 50).
     * 
     * @param height
     *      The NumberFields height (which has to be greater than 20).
     * 
     * @param edgeValues
     *      True if there should be edge values.
     * 
     * @param maximumValue
     *      The maximum value the NumberField can reach.
     * 
     * @param minimumValue
     *      The minimum value the NumberField can reach.
     */
    public NumberField(int width, int height, boolean edgeValues, int minimumValue, int maximumValue) throws IllegalArgumentException {
        this(width, height, Color.white, Color.black, 0, edgeValues, minimumValue, maximumValue);
    }
    
    /**
     * Creates a new NumberField of the given size with black letters on white background and a starting text.
     * 
     * @param width
     *      The NumberFields width (which has to be greater than 50).
     * 
     * @param height
     *      The NumberFields height (which has to be greater than 20).
     * 
     * @param number
     *      The number that is shown directly.
     */
    public NumberField(int width, int height, int number) throws IllegalArgumentException {
        this(width, height, Color.white, Color.black, number, false, 0, 0);
    }
    
    /**
     * Creates a new NumberField of the given size with black letters on white background and a starting text.
     * 
     * @param width
     *      The NumberFields width (which has to be greater than 50).
     * 
     * @param height
     *      The NumberFields height (which has to be greater than 20).
     * 
     * @param number
     *      The number that is shown directly.
     * 
     * @param edgeValues
     *      True if there should be edge values.
     * 
     * @param maximumValue
     *      The maximum value the NumberField can reach.
     * 
     * @param minimumValue
     *      The minimum value the NumberField can reach.
     */
    public NumberField(int width, int height, int number, boolean edgeValues, int minimumValue, int maximumValue) throws IllegalArgumentException {
        this(width, height, Color.white, Color.black, number, edgeValues, minimumValue, maximumValue);
    }
    
    /**
     * Creates a new TextField of the given size and the given colors.
     * 
     * @param width
     *      The TextFields width (which has to be greater than 50).
     * 
     * @param height
     *      The TextFields height (which has to be greater than 20).
     * 
     * @param bgColor
     *      The color of the TextFields background.
     * 
     * @param textColor
     *      The color of the text.
     */
    public NumberField(int width, int height, Color bgColor, Color textColor) throws IllegalArgumentException {
        this(width, height, bgColor, textColor, 0, false, 0, 0);
    }
    
    /**
     * Creates a new TextField of the given size and the given colors.
     * 
     * @param width
     *      The TextFields width (which has to be greater than 50).
     * 
     * @param height
     *      The TextFields height (which has to be greater than 20).
     * 
     * @param bgColor
     *      The color of the TextFields background.
     * 
     * @param textColor
     *      The color of the text.
     * 
     * @param edgeValues
     *      True if there should be edge values.
     * 
     * @param maximumValue
     *      The maximum value the NumberField can reach.
     * 
     * @param minimumValue
     *      The minimum value the NumberField can reach.
     */
    public NumberField(int width, int height, Color bgColor, Color textColor, boolean edgeValues, int minimumValue, int maximumValue) throws IllegalArgumentException {
        this(width, height, bgColor, textColor, 0, edgeValues, minimumValue, maximumValue);
    }
    
    /**
     * Creates a new TextField of the given size, the given colors and a starting text.
     * 
     * @param width
     *      The TextFields width (which has to be greater than 50).
     * 
     * @param height
     *      The TextFields height (which has to be greater than 20).
     * 
     * @param bgColor
     *      The color of the TextFields background.
     * 
     * @param textColor
     *      The color of the text.
     */
    public NumberField(int width, int height, Color bgColor, Color textColor, int number) throws IllegalArgumentException {
        this(width, height, bgColor, textColor, number, false, 0, 0);
    }
    
    /**
     * Creates a new TextField of the given size, the given colors and a starting text.
     * 
     * @param width
     *      The TextFields width (which has to be greater than 50).
     * 
     * @param height
     *      The TextFields height (which has to be greater than 20).
     * 
     * @param bgColor
     *      The color of the TextFields background.
     * 
     * @param textColor
     *      The color of the text.
     * 
     * @param edgeValues
     *      True if there should be edge values.
     * 
     * @param maximumValue
     *      The maximum value the NumberField can reach.
     * 
     * @param minimumValue
     *      The minimum value the NumberField can reach.
     */
    public NumberField(int width, int height, Color bgColor, Color textColor, int number, boolean edgeValues, int minimumValue, int maximumValue) throws IllegalArgumentException {
        if (width < 50) {
            throw new IllegalArgumentException("The width of the number field has to be greater or equal 50");
        }
        else if (height < 20) {
            throw new IllegalArgumentException("The height of the number field has to be greater or equal 20");
        }
        else if (minimumValue > maximumValue) {
            throw new IllegalArgumentException("The minimum value(" + minimumValue + ") has to be less than the maximum value(" + maximumValue + ").");
        }
        this.bgColor = bgColor;
        this.textColor = textColor;
        this.text = Integer.toString(number);
        this.edgeValues = edgeValues;
        this.maximumValue = maximumValue;
        this.minimumValue = minimumValue;
        upButton = new Arrow_Button("up", this, height/2, height/2);
        downButton = new Arrow_Button("down", this, height/2, height/2);
        getImage().clear();
        getImage().scale(width, height);
        textFontSize = height - 10;
        resetImage();
        displayText();
    }
    
    /**
     * Assigns this field a number.
     * This method is called when the object is added to the world.
     */
    public void addedToWorld(World world) {
        numberFieldNumber = getWorld().getObjects(NumberField.class).size();
        getWorld().addObject(upButton, getX() + getImage().getWidth()/2 - upButton.getImage().getWidth()/2 - 4, getY() - getImage().getHeight()/2 + upButton.getImage().getHeight()/2);
        getWorld().addObject(downButton, getX() + getImage().getWidth()/2 - downButton.getImage().getWidth()/2 - 4, getY() + getImage().getHeight()/2 - downButton.getImage().getHeight()/2 - 4);
    }
    
    /**
     * Control the NumberFields action.
     */
    public void act() {
        if (Greenfoot.mouseClicked(this)) {
            activeNumberField = numberFieldNumber;
            active = true;
        }
        if (active) {
            if (activeNumberField != numberFieldNumber) {
                active = false;
                cursorActive = false;
                displayText();
                return;
            }
            if (System.currentTimeMillis() - cursorTime > 750) {
                cursorTime = System.currentTimeMillis();
                cursorActive = !cursorActive;
            }
            input = Greenfoot.getKey();
            if (input == "backspace" && text.length() != 0) {
                text = text.substring(0, text.length()-1);
            }
            else if (input == "enter") {
                setActiveNumberField();
            }
            else if (input != null) {
                try {
                    Integer.parseInt(input);
                    text += input;
                }
                catch (NumberFormatException nfe) {
                    //nfe.printStackTrace();
                }
            }
            checkValue();
            displayText();
        }
        else {
            if (activeNumberField == numberFieldNumber) {
                active = true;
            }
        }
    }
    
    /**
     * Remove the numberfield and the arrow buttons.
     */
    public void remove() {
        if (getWorld() != null) {
            getWorld().removeObject(upButton);
            getWorld().removeObject(downButton);
            getWorld().removeObject(this);
        }
    }
    
    /**
     * Change the location of the NumberField and the arrowbuttons.
     */
    public void setLocation(int x, int y) {
        upButton.setLocation(x + getImage().getWidth()/2 - upButton.getImage().getWidth()/2 - 4, y - getImage().getHeight()/2 + upButton.getImage().getHeight()/2);
        downButton.setLocation(x + getImage().getWidth()/2 - downButton.getImage().getWidth()/2 - 4, y + getImage().getHeight()/2 - downButton.getImage().getHeight()/2 - 4);
        super.setLocation(x, y);
    }
    
    /**
     * Display the text onto the NumberField.
     */
    private void displayText() {
        GreenfootImage textImage = new GreenfootImage(text, textFontSize, textColor, new Color(0, 0, 0, 0));
        resetImage();
        getImage().drawImage(textImage, (textImage.getWidth() > getImage().getWidth() - (upButton.getImage().getWidth() + 15) ? -(textImage.getWidth() - getImage().getWidth()) - (upButton.getImage().getWidth() + 15) : 5), (getImage().getHeight() / 2 - textImage.getHeight() / 2));
        getImage().setColor(textColor);
        if (cursorActive) {
            getImage().fillRect((textImage.getWidth() > getImage().getWidth() - (upButton.getImage().getWidth() + 15) ? getImage().getWidth() - (upButton.getImage().getWidth() + 12) : textImage.getWidth() + 7), getImage().getHeight() / 2 - textFontSize / 2, 2, textFontSize);
        }
        getImage().setColor(bgColor);
        getImage().fillRect(0, 0, 3, getImage().getHeight()-2);
    }
    
    /**
     * Clears the image of the TextField so that it is empty again.
     */
    private void resetImage() {
        getImage().setColor(bgColor);
        getImage().fill();
        getImage().setColor(Color.black);
        getImage().fillRect(0, getImage().getHeight()-2, getImage().getWidth(), 3);
        getImage().fillRect(getImage().getWidth()-2, 0, 3, getImage().getHeight());
    }
    
    /**
     * Set the active NumberField to the given number.
     * 
     * @param activeNumberField
     *      The number of the NumberField that is activated.
     */
    public void setActiveNumberField(int activeNumberField) {
        this.activeNumberField = activeNumberField;
    }
    /**
     * Set the active NumberField to the given numberField.
     * 
     * @param numberField
     *      The NumberField that is activated.
     */
    public void setActiveNumberField(NumberField numberField) {
        activeNumberField = numberField.getNumber();
    }
    /**
     * Set the active TextField to the next textfield.
     */
    public void setActiveNumberField() {
        activeNumberField++;
        if (activeNumberField > getWorld().getObjects(NumberField.class).size()) {
            activeNumberField = 1;
        }
    }
    
    /**
     * Checks whether the value of the NumberField is to less or to high.
     * If it's to high or to less it's corekted.
     */
    private void checkValue() {
        if (edgeValues && text != null && text != "") {
            try {
                if (Integer.parseInt(text) > maximumValue) {
                    text = Integer.toString(maximumValue);
                }
                else if (Integer.parseInt(text) < minimumValue) {
                    text = Integer.toString(minimumValue);
                }
            }
            catch (NumberFormatException nfe) {
                //nfe.printStackTrace();
            }
        }
    }
    
    /**
     * Increments the current value.
     */
    public void incrementValue() {
        if (text != "" && text != null) {
            try {
                text = Integer.toString(Integer.parseInt(text) + 1);
            }
            catch (NumberFormatException nfe) {
                //nfe.printStackTrace();
                text = "1";
            }
        }
        else {
            text = "1";
        }
        checkValue();
    }
    /**
     * Decrements the current value.
     */
    public void decrementValue() {
        if (text != "" && text != null) {
            try {
                text = Integer.toString(Integer.parseInt(text) - 1);
            }
            catch (NumberFormatException nfe) {
                //nfe.printStackTrace();
                text = "-1";
            }
        }
        else {
            text = "-1";
        }
        checkValue();
    }
    
    /**
     * Returns the counting number of this numberField.
     * 
     * @return 
     *      The counting number of this numberField.
     */
    public int getNumber() {
        return numberFieldNumber;
    }
    
    /**
     * Returns the value of this numberField.
     * 
     * @return 
     *      The value of the numberField if it is an integer.
     *      If It's no integer value 0 is returned.
     */
    public int getValue() {
        int value;
        try {
            value = Integer.parseInt(text);
        }
        catch (NumberFormatException nfe) {
            //nfe.printStackTrace();
            value = 0;
        }
        return value;
    }
    
    /**
     * Check whether this numberField is active.
     * 
     * @return
     *      Returns true if the numberField is active at the moment and false if not.
     */
    public boolean isActive() {
        return active;
    }
    
    /**
     * Returns the backgroundcolor of this NumberField.
     * 
     * @return
     *      The backgroundcolor of this NumberField.
     */
    public Color getBackgroundColor() {
        return bgColor;
    }
    /**
     * Set the backgroundcolor to the given color.
     * 
     * @param bgColor
     *      The new backgroundcolor.
     */
    public void setBackgroundColor(Color bgColor) {
        this.bgColor = bgColor;
    }
    
    /**
     * Returns the textcolor of this NumberField.
     * 
     * @return
     *      The textcolor of this NumberField.
     */
    public Color getTextColor() {
        return textColor;
    }
    /**
     * Set the textcolor to the given color.
     * 
     * @param textColor
     *      The new textcolor.
     */
    public void setTextColor(Color textColor) {
        this.textColor = textColor;
    }
}