import greenfoot.*;
import java.io.IOException;
import java.util.List;
import java.util.ArrayList;

/**
 * Profiles are used to store the players progress and pointscore.
 * They work using the UserInfo while playing online or Files while playing offline.
 * 
 * @author Gevater_Tod4711
 * @version 1.0
 */
public class Profile
{
    private int reachedLevel;
    
    private UserInfo userInfo;
    
    public Profile() {
        if (GreenfootToolkit.getToolkit().playingOnline() && UserInfo.isStorageAvailable()) {
            loadUserInfoProfile();
        }
        else {
            if (GreenfootToolkit.getToolkit().fileExisting("profile_4c98fn5c3gz1wa")) {
                try {
                    loadProfile();
                }
                catch (IllegalArgumentException iae) {
                    iae.printStackTrace();
                    createNewProfile();
                }
            }
            else {
                createNewProfile();
            }
        }
    }
    
    public void loadProfile() throws IllegalArgumentException {
        List<String> profileText = GreenfootToolkit.getToolkit().loadFile("profile_4c98fn5c3gz1wa");
        if (profileText.size() != 1) {
            throw new IllegalArgumentException("Loaded file different in length");
        }
        try {
            reachedLevel = Integer.parseInt(profileText.get(0));
        }
        catch (NumberFormatException nfe) {
            nfe.printStackTrace();
            throw new IllegalArgumentException("Loaded file invalid");
        }
    }
    public void loadUserInfoProfile() {
        userInfo = UserInfo.getMyInfo();
        reachedLevel = userInfo.getInt(0);
        if (reachedLevel < 1) {
            reachedLevel = 1;
            createNewUserInfoProfile();
        }
    }
    
    public void createNewProfile() {
        GreenfootToolkit.getToolkit().saveFile("profile_4c98fn5c3gz1wa", false, new String[] {Integer.toString(1)});
        reachedLevel = 1;
    }
    public void createNewUserInfoProfile() {
        userInfo.setInt(0, 1);
        userInfo.store();
    }
    
    public void saveProfile() throws IOException {
        if (userInfo != null) {
            saveUserInfoProfile();
        }
        else {
            saveProfileFile();
        }
    }
    public void saveProfileFile() throws IOException {
        if (!GreenfootToolkit.getToolkit().saveFile("profile_4c98fn5c3gz1wa", false, new String[] {Integer.toString(reachedLevel)})) {
            throw new IOException("Fatal Error occured: Profile couldn't be saved");
        }
    }
    public void saveUserInfoProfile() {
        userInfo.setInt(0, reachedLevel);
        userInfo.store();
    }
    
    public UserInfo getUserInfo() {
        return userInfo;
    }
    
    public int getReachedLevel() {
        return reachedLevel;
    }
    public void setReachedLevel(int reachedLevel) {
        if (userInfo != null) {
            this.reachedLevel = userInfo.getInt(0);
        }
        if (this.reachedLevel < reachedLevel) {
            this.reachedLevel = reachedLevel;
        }
    }
}