import greenfoot.*;
import java.util.List;
import java.util.ArrayList;

/**
 * In this class all the settings of the game are saved.
 * Most of the values can't be changed after compiling because they are declared 'final'.
 * 
 * The values should be set before constructing the game because changing the values may cause that some passages of the game are not playable anymore.
 * In this class the settings for bonus point values, the hero controll, the images and sounds of the textur and sound packages and the object specific values are saved.
 * 
 * If you want to change e.g. the movement, the moving speed or any other values of the hero or the enemies you should do that here and not in the classes themselves.
 * 
 * @author Gevater_Tod4711
 * @version 1.0
 */
public abstract class Settings  
{
    //Key settings for the hero movement;
    public static String jump = "space";
    public static String setGravityDirectionUp = "up";
    public static String setGravityDirectionDown = "down";
    public static String setGravityDirectionLeft = "left";
    public static String setGravityDirectionRight = "right";
    
    public static Profile profile = new Profile();
    
    
    //Jump'N'Run World;
    public static final double GRAVITY = 0.15;
    
    
    //Player subclasses;
    
    //Hero;
    public static final double HERO_MAX_MOVEMENT_AIR = 6.5;
    public static final double HERO_FIRST_JUMP_MOVEMENT = 5;
    
    
    
    
    //Image settings: You can use your own texturpack here;
    public static final String TEXTUR_PACK = "GravityChaosTexturPack";
    
    //Images for standart version;
    public static final GreenfootImage hero = new GreenfootImage(TEXTUR_PACK + "/hero.png");
    public static final GreenfootImage texturEarth = new GreenfootImage(TEXTUR_PACK + "/earth.png");
    public static final GreenfootImage texturLava = new GreenfootImage(TEXTUR_PACK + "/lava.png");
    public static final GreenfootImage texturAir = new GreenfootImage(TEXTUR_PACK + "/air.png");
    public static final GreenfootImage textur = new GreenfootImage(TEXTUR_PACK + "/textur_0.png");
    public static final GreenfootImage endGate = new GreenfootImage(TEXTUR_PACK + "/endGate.png");
    public static final GreenfootImage mainMenu = new GreenfootImage(TEXTUR_PACK + "/mainMenu.png");
    public static final GreenfootImage levelMenu = new GreenfootImage(TEXTUR_PACK + "/levelMenu.png");
    public static final GreenfootImage breakMenu = new GreenfootImage(TEXTUR_PACK + "/breakMenu.png");
    public static final GreenfootImage endScreen = new GreenfootImage(TEXTUR_PACK + "/endScreen.png");
    
    
    
    //Sound settings: You can use your own sound package here;
    public static final String SOUND_PACKAGE = "GravityChaosSoundPackage";
    
    public static int soundVolume = 85;
    public static boolean backgroundMusic = false;
    
    public static final String jumpSound = SOUND_PACKAGE + "/jump.mp3";
    public static final String burnSound = SOUND_PACKAGE + "/burn.wav";
    public static final String pauseSound = SOUND_PACKAGE + "/pause.wav";
    
    private static java.util.List<GreenfootImage> createImages(String image) {
        ArrayList<GreenfootImage> images = new ArrayList<GreenfootImage>();
        GreenfootImage temp;
        for (int i = 0; i < 10; i++) {
            try {
                temp = new GreenfootImage(TEXTUR_PACK + "/" + image + "_" + Integer.toString(i) + ".png");
                images.add(temp);
            }
            catch (Exception e) {
                //e.printStackTrace();
                break;
            }
        }
        return images;
    }
    
    private static java.util.List<java.util.List<GreenfootImage>> createImageLists(String image) {
        List<List<GreenfootImage>> imageLists = new ArrayList<List<GreenfootImage>>();
        ArrayList<GreenfootImage> images;
        GreenfootImage temp;
        for (int i = 0; true; i++) {
            try {
                temp = new GreenfootImage(TEXTUR_PACK + "/" + image + "_" + Integer.toString(i) + "_0.png");
                images = new ArrayList<GreenfootImage>();
                for (int j = 0; true; j++) {
                    try {
                        temp = new GreenfootImage(TEXTUR_PACK + "/" + image + "_" + Integer.toString(i) + "_" + Integer.toString(j) + ".png");
                        images.add(temp);
                    }
                    catch (Exception e) {
                        //e.printStackTrace();
                        break;
                    }
                }
                imageLists.add(images);
            }
            catch (Exception e) {
                //e.printStackTrace();
                break;
            }
        }
        return imageLists;
    }
}